Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit d2fd1f5


[ROCm/clr commit: 2557000b56]
This commit is contained in:
Alex Voicu
2017-11-29 21:36:29 +00:00
والد 4d18ad9ebe
کامیت a1d5f0ab0c
62فایلهای تغییر یافته به همراه152 افزوده شده و 152 حذف شده
@@ -35,7 +35,7 @@ THE SOFTWARE.
__global__ void floatMath(hipLaunchParm lp, float *In, float *Out) {
int tid = threadIdx.x + blockIdx.x * blockDim.x;
int tid = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
Out[tid] = __cosf(In[tid]);
Out[tid] = __exp10f(Out[tid]);
Out[tid] = __expf(Out[tid]);